#
# spec file for package phoronix-test-suite
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           phoronix-test-suite
Version:        10.8.4
Release:        bp155.2.5
Summary:        Comprehensive test and benchmarking platform
License:        GPL-3.0-only
Group:          System/Benchmark
URL:            http://www.phoronix-test-suite.com/
Source0:        https://phoronix-test-suite.com/releases/phoronix-test-suite-%{version}.tar.gz
Patch0:         harden_phoromatic-client.service.patch
Patch1:         harden_phoromatic-server.service.patch
Patch2:         harden_phoronix-result-server.service.patch
Patch3:         fix-shebang.patch
Patch4:         fix-CVE-2022-40704.patch
# https://github.com/phoronix-test-suite/phoronix-test-suite/issues/505 [bsc#1175508]
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  shared-mime-info
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
%if 0%{?suse_version} >= 1550
Requires:       php8
Requires:       php8-curl
Requires:       php8-dom
Requires:       php8-gd
Requires:       php8-openssl
Requires:       php8-pcntl
Requires:       php8-posix
Requires:       php8-sockets
Requires:       php8-zip
Requires:       php8-zlib
%else
Requires:       php7
Requires:       php7-curl
Requires:       php7-dom
Requires:       php7-gd
Requires:       php7-json
Requires:       php7-openssl
Requires:       php7-pcntl
Requires:       php7-posix
Requires:       php7-sockets
Requires:       php7-zip
Requires:       php7-zlib
%endif
Requires:       xdg-utils
BuildArch:      noarch
%systemd_requires

%description
The Phoronix Test Suite can be used for simply comparing your
computer's performance or internal quality assurance purposes under
Linux. Results from the Phoronix Test Suite are displayed in a results
viewer with optional support for uploading them to PTS Global. This
software is based upon the internal tools and extensive Linux
benchmarking work done by Phoronix since 2004, with input from tier-one
computer hardware vendors. The Phoronix Test Suite ships with over 50
tests and 20 suites.

%prep
%autosetup -p1 -n %{name}
find ob-cache -type f -name *.sh -exec chmod +x {} \;

%build

%install
export DESTDIR=%{buildroot}
./install-sh ${_prefix}
%suse_update_desktop_file -i -n %{name}
%suse_update_desktop_file -i -n %{name}-launcher
%fdupes -s %{buildroot}
mkdir %{buildroot}%{_sbindir}
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rcphoromatic-client
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rcphoromatic-server

rm  %{buildroot}%{_datadir}/%{name}/pts-core/static/sample-pts-client-update-script.sh
rm  %{buildroot}%{_datadir}/%{name}/pts-core/external-test-dependencies/scripts/install-macports-packages.sh

%pre
%service_add_pre phoromatic-client.service phoromatic-server.service phoronix-result-server.service

%post
%if 0%{?suse_version} < 1330
%desktop_database_post
%icon_theme_cache_post
%mime_database_post
%endif
%service_add_post phoromatic-client.service phoromatic-server.service phoronix-result-server.service

%preun
%service_del_preun phoromatic-client.service phoromatic-server.service phoronix-result-server.service

%postun
%if 0%{?suse_version} < 1330
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun
%endif
%service_del_postun phoromatic-client.service phoromatic-server.service phoronix-result-server.service

%files
%defattr(-,root,root)
%license COPYING
%doc AUTHORS ChangeLog README.md
%doc %{_datadir}/doc/%{name}
%doc %{_mandir}/man1/%{name}.1.gz
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/*
%{_datadir}/icons/hicolor/
%config(noreplace) %{_sysconfdir}/bash_completion.d/*
%{_datadir}/mime/packages/*
%dir %{_datadir}/appdata
%{_sbindir}/rcphoromatic-client
%{_sbindir}/rcphoromatic-server
%{_unitdir}/phoromatic-client.service
%{_unitdir}/phoromatic-server.service
%{_unitdir}/phoronix-result-server.service
%{_datadir}/appdata/phoronix-test-suite.appdata.xml

%changelog
* Thu Dec  8 2022 Martin Liška <mliska@suse.cz>
- Add fix-CVE-2022-40704.patch that fixes boo#1206079.
* Wed Nov 30 2022 pgajdos@suse.com
- require php8 in TW
* Mon Sep  5 2022 Martin Liška <mliska@suse.cz>
- Remove ownership of man1 folder.
* Thu Sep  1 2022 Martin Liška <mliska@suse.cz>
- Update to version 10.8.4:
  * pts-core: Allow sub-folders within PTS_EXTRA_SYSTEM_LOGS_DIR when uploading to Phoromatic server
  * pts-core: Fix TOTAL_LOOP_TIME handling
  * pts-core: openSUSE external dependency handling fixes
  * phodevi: Support for reporting video BIOS version
  * phodevi: Budgie desktop version detection
  * phodevi: Avoid deprecated wmic usage on Windows
  * phoromatic: Input sanitization updates in the result viewer
- Add fix-shebang.patch that fixes a bad shebang.
- Use autosetup.
* Fri Feb 25 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- version update to 10.8.2
  * Fix CVE-2022-0157: Improper Neutralization of Input During Web
    Page Generation ('Cross-site Scripting')
  * Fix CVE-2022-0196, CVE-2022-0197, CVE-2022-0238:
    Cross-Site Request Forgery
  * Fix CVE-2022-0571: Cross-site Scripting (XSS)
  * For detailed list of changes see ChangeLog
* Tue Oct 19 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_phoromatic-client.service.patch
  * harden_phoromatic-server.service.patch
  * harden_phoronix-result-server.service.patch
* Fri Jul  2 2021 pgajdos@suse.com
- version update to 10.4.0
  * For detailed list of changes see ChangeLog
- deleted patches
  - phoronix-test-suite-9703b4b.patch (upstreamed)
* Fri Feb 26 2021 pgajdos@suse.com
- version update to 10.2.2
  * For detailed list of changes see ChangeLog
- added patches [bsc#1175508] (internal)
  fix https://github.com/phoronix-test-suite/phoronix-test-suite/issues/505
  + phoronix-test-suite-phoronix-test-suite-9703b4b.patch
* Mon May 25 2020 ecsos <ecsos@opensuse.org>
- Update to version 9.6.0
  * For detailed list of changes see ChangeLog
- Change to new download url.
* Fri May  4 2018 simonizor@protonmail.com
- Update to version 7.8.0
  * For detailed list of changes see ChangeLog
* Wed Feb 14 2018 joop.boonen@opensuse.org
- Added missing dependancy php-sockets
- Used the general php name in stead of php{version}
* Mon Jan  8 2018 mpluskal@suse.com
- Update to version 7.6.0:
  * For detailed list of changes see ChangeLog
- Do not run post scriplets on Tumbleweed where they are not needed
* Fri Oct  6 2017 mpluskal@suse.com
- Update to version 7.4.0:
  * For detailed list of changes see ChangeLog
- Drop phoronix-test-suite-php-gtk-ini.patch
- Switch to php7
* Fri Jun 16 2017 jhura@suse.com
- Update to version 7.2.0:
  * For detailed list of changes see ChangeLog
* Thu May 18 2017 dziolkowski@suse.com
- Update to version 7.0.1:
  * For detailed list of changes see ChangeLog
* Thu Mar 16 2017 mpluskal@suse.com
- Update to version 7.0.0:
  * For detailed list of changes see ChangeLog
* Wed Dec  7 2016 jhura@suse.com
- Update to 6.8.0
  * For detailed list of changes see CHANGE-LOG.
* Sat Mar  5 2016 mpluskal@suse.com
- Update to 6.2.1
  * For detailed list of changes see CHANGE-LOG.
* Sat Nov 28 2015 kkaempf@suse.com
- Update to 6.0.1
  * For detailed list of changes see CHANGE-LOG.
* Tue Jul  7 2015 mailaender@opensuse.org
- enable MIME support
* Tue Jul  7 2015 mailaender@opensuse.org
- update to version 5.8.1
  * For detailed list of changes see CHANGE-LOG.
* Mon Apr 13 2015 jhura@suse.com
- Update to version 5.6.0
  * For detailed list of changes see CHANGE-LOG.
* Thu Feb  5 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Add dependencies for unit files
- Update to version 5.4.1:
  * pts-core: Update AppData and systemd service files
  * pts-core: Add csv-dump-frame-latencies support to result parser
  * phoromatic: Improve formatting of result strings when merging random result files together
  * phoromatic: Add enterprise-setup sub-command
  * phoromatic: Attempt to detect and report IP address next to requested MAC address claim on the system claim page
* Wed Sep  3 2014 dsterba@suse.cz
- Build version 5.2.1
* Sat Jan  5 2013 joop.boonen@opensuse.org
- Build version 4.2.0
* Tue Nov 27 2012 joop.boonen@opensuse.org
- Build version 4.0.1
* Thu Apr 26 2012 joop.boonen@opensuse.org
- Added cross distro build
- Added phoronix-test-suite-launcher.desktop
- Passed spec file through spec cleaner
* Tue Apr 24 2012 mseben@gmail.com
- added sles10_fixs.patch to fix sles10 builds
- update to 3.8.0-Bygland (for full changelog see CHANGE-LOG file)
  - pts-core: Support longer titles on result files (64 characters expanded on OpenBenchmarking.org)
  - pts-core: Wine/Windows fixes for items reported by Stefan Dösinger
  - pts-core: Minor improvement for analyzing compiler option string differences
  - pts-core: Fix for result file analyzing sometimes not returning hardware changes
  - pts-core: Better handling for detecting Wine trackers / other trackers using a mix of short SHA1s
  - phodevi: Support for determining and appending release dates on GCC snapshots/pre-releases
* Sat Jan  7 2012 joop.boonen@opensuse.org
- Build version 3.6.1
* Mon Jul  4 2011 joop.boonen@opensuse.org
- Build version 3.2.1
* Wed Mar 16 2011 joop.boonen@opensuse.org
- Build version 3.0.1
* Mon Mar 14 2011 lslezak@suse.cz
- Updated to 3.0.0
* Thu Sep  9 2010 joop.boonen@opensuse.org
- Build version 2.8.1
* Tue Sep  7 2010 joop.boonen@opensuse.org
- Build version 2.8.0
- It's a noarch package as it doesn't contain binaries
* Mon Sep  6 2010 joop.boonen@opensuse.org
- Build according to:
- http://oops.opsat.net/doc/gtk/configure-php.html
  as the old build breaks php cli
* Tue Jun 29 2010 joop.boonen@opensuse.org
- Build version 2.6.1
* Thu Mar 18 2010 joop.boonen@opensuse.org
- Build version 2.4.1
* Wed Jan  6 2010 joop.boonen@opensuse.org
- Build version 2.2.0
* Wed Aug  5 2009 joop_boonen@opensuse.org
- Build version 2.0.0
* Tue May 19 2009 joop_boonen@opensuse.org
- Build version 1.8.1
- Some improvements to the spec file
  with improvements 1.2.1 package of some-guy <muhammedu@gmail.com>
* Thu Sep  4 2008 kyu@suse.de
- initial release
